@@ -1,6 +1,4 @@
 
-# $Id: Phonetic.pm,v 1.9 2008/09/07 03:23:24 Martin Exp $
-
 =head1 NAME
 
 Lingua::Alphabet::Phonetic - map ABC's to phonetic alphabets
@@ -32,7 +30,7 @@ use strict;
 use warnings;
 
 our
-$VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/o);
+$VERSION = 1.11;
 
 =item new
 
@@ -115,7 +113,7 @@ This software is released under the same license as Perl itself.
 
 =head1 AUTHOR
 
-Martin Thurn (mthurn@cpan.org).
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
